@@ -1,31 +1,42 @@
 """The ``cli`` package is a framework for making simple, correct command
 line applications in Python. With ``cli``, you can quickly add standard 
-`logging`_, `testing`_, `profiling`_ to your CLI apps. To make it easier
-to do the right thing, ``cli`` wraps all of these tools into a single,
-consistent application interface.
+`command line parsing`_, `logging`_ and `profiling`_ to your CLI apps. 
+To make it easier to do the right thing, ``cli`` wraps all of these tools 
+into a single, consistent application interface.
 
+.. _command line parsing: http://www.python.org/dev/peps/pep-0389/#deprecation-of-optparse
 .. _logging:    http://docs.python.org/library/logging.html
-.. _testing:    http://docs.python.org/library/unittest.html
 .. _profiling:  http://docs.python.org/library/profile.html
 """
 
+# pragma: no cover
+
 __project__ = "pyCLI"
-__version__ = "0.3.4"
+__version__ = "1.0"
 __package__ = "cli"
-__description__ = "Simple, Object-Oriented approach to Python CLI apps"
+__description__ = "Simple, object-oriented approach to Python CLI apps"
 __author__ = "Will Maier"
 __author_email__ = "will@m.aier.us"
-__url__ = "http://code.lfod.us/cli"
+__url__ = "http://packages.python.org/pyCLI/"
 
 # See http://pypi.python.org/pypi?%3Aaction=list_classifiers.
-__classifiers__ = [] 
+__classifiers__ = [
+    "Programming Language :: Python :: 2.4",
+    "Programming Language :: Python :: 2.5",
+    "Programming Language :: Python :: 2.6",
+    "Programming Language :: Python :: 2.7",
+    "Programming Language :: Python :: 3",
+    "Topic :: Software Development :: Libraries :: Application Frameworks",
+    "Environment :: Console",
+    "Development Status :: 5 - Production/Stable",
+] 
 __keywords__ = "command line application framework"
 
 __requires__ = []
 
 # The following is modeled after the ISC license.
 __copyright__ = """\
-2009 Will Maier <will@m.aier.us>
+2009-2010 Will Maier <will@m.aier.us>
 
 Permission to use, copy, modify, and distribute this software for any
 purpose with or without fee is hereby granted, provided that the above
@@ -53,4 +64,6 @@ __todo__ = """\
 """
 
 # Import API-level elements.
-from app import *
+from cli.app import *
+from cli.daemon import *
+from cli.log import *
